.. image:: https://img.shields.io/pypi/v/jaraco.site.svg
   :target: https://pypi.org/project/jaraco.site

.. image:: https://img.shields.io/pypi/pyversions/jaraco.site.svg

.. image:: https://img.shields.io/pypi/dm/jaraco.site.svg

.. image:: https://img.shields.io/travis/jaraco/skeleton/master.svg
   :target: http://travis-ci.org/jaraco/skeleton

License is indicated in the project metadata (typically one or more
of the Trove classifiers). For more details, see `this explanation
<https://github.com/jaraco/skeleton/issues/1>`_.
